@@ -143,9 +143,10 @@ save.dta13 <- function(data, file, data.label=NULL, time.stamp=TRUE,
     data <- data.frame(rownames= rwn,
                        data, stringsAsFactors = F)
   }
+  rownames(data) <- NULL
 
   if (convert.underscore) {
-    names(data) <- gsub("[^a-zA-Z\\d:]", "_", names(data))
+    names(data) <- gsub("[^a-zA-Z0-9:]", "_", names(data))
   }
 
   filepath <- path.expand(file)
@@ -277,6 +278,7 @@ save.dta13 <- function(data, file, data.label=NULL, time.stamp=TRUE,
 
   # recode character variables. 118 wants utf-8, so encoding may be required
   if(doRecode) {
+    #TODO: use seq_len ?
     for(v in (1:ncol(data))[vartypen == "character"]) {
       data[, v] <- save.encoding(data[, v], toEncoding)
     }
@@ -288,10 +290,11 @@ save.dta13 <- function(data, file, data.label=NULL, time.stamp=TRUE,
     max(nchar(x, type="byte")) + 1
   }
   str.length <- sapply(data[vartypen == "character"], FUN=maxchar)
+  str.length[str.length > sstr] <- sstrl
 
   for (v in names(vartypen[vartypen == "character"]))
   {
-    str.length[str.length > sstr] <- sstrl
+   # str.length[str.length > sstr] <- sstrl # no loop necessary!
 
     vartypen[[v]] <- str.length[[v]]
   }
