@@ -21,11 +21,11 @@
 using namespace Rcpp;
 using namespace std;
 
-//' Writes the binary Stata file
-//'
-//' @param filePath The full systempath to the dta file you want to export.
-//' @param dat an R-Object of class data.frame.
-//' @export
+// Writes the binary Stata file
+//
+// @param filePath The full systempath to the dta file you want to export.
+// @param dat an R-Object of class data.frame.
+// @export
 // [[Rcpp::export]]
 int stata_pre13_save(const char * filePath, Rcpp::DataFrame dat)
 {
@@ -296,7 +296,9 @@ int stata_pre13_save(const char * filePath, Rcpp::DataFrame dat)
           // store numeric as Stata double (double)
         case 255:
         {
-          double val_d = as<NumericVector>(dat[i])[j];
+          double val_d = 0;
+
+          val_d = as<NumericVector>(dat[i])[j];
 
           if ( (val_d == NA_REAL) | R_IsNA(val_d) )
             val_d = STATA_DOUBLE_NA;
@@ -308,11 +310,15 @@ int stata_pre13_save(const char * filePath, Rcpp::DataFrame dat)
           // float
         case 254:
         {
-          double val_d = as<NumericVector>(dat[i])[j];
-          float val_f = (float)(val_d);
+          double val_d = 0;
+          float  val_f = 0;
+
+          val_d = as<NumericVector>(dat[i])[j];
 
           if ((val_d == NA_REAL) | (R_IsNA(val_d)) )
             val_f = STATA_FLOAT_NA;
+          else
+            val_f = (float)(val_d);
 
           writebin(val_f, dta, swapit);
 
@@ -321,7 +327,9 @@ int stata_pre13_save(const char * filePath, Rcpp::DataFrame dat)
           // store integer as Stata long (int32_t)
         case 253:
         {
-          int32_t val_l = as<IntegerVector>(dat[i])[j];
+          int32_t val_l = 0;
+
+          val_l = as<IntegerVector>(dat[i])[j];
 
           if ( (val_l == NA_INTEGER) | (R_IsNA(val_l)) )
           {
@@ -338,17 +346,15 @@ int stata_pre13_save(const char * filePath, Rcpp::DataFrame dat)
           // int
         case 252:
         {
-          union v {
-            int32_t   l;
-            int16_t   i;
-          } val;
+          int16_t val_i = 0;
+          int32_t val_l = 0;
 
-          val.l = as<IntegerVector>(dat[i])[j];
+          val_l = as<IntegerVector>(dat[i])[j];
 
-          int16_t val_i = val.i;
-
-          if (val.l == NA_INTEGER)
+          if (val_l == NA_INTEGER)
             val_i = STATA_SHORTINT_NA;
+          else
+            val_i = val_l;
 
           writebin(val_i, dta, swapit);
 
@@ -357,20 +363,18 @@ int stata_pre13_save(const char * filePath, Rcpp::DataFrame dat)
           // byte
         case 251:
         {
-          union v {
-            int32_t   l;
-            int8_t    b;
-          } val;
+          int8_t  val_b = 0;
+          int32_t val_l = 0;
 
-          val.l = as<IntegerVector>(dat[i])[j];
+          val_l = as<IntegerVector>(dat[i])[j];
 
-          int8_t val_b = val.b;
-
-          if (val.l == NA_INTEGER) {
+          if (val_l == NA_INTEGER) {
             if (version>104)
               val_b = STATA_BYTE_NA;
             else
               val_b = STATA_BYTE_NA_104;
+          } else {
+            val_b = val_l;
           }
 
           writebin(val_b, dta, swapit);
