@@ -513,7 +513,8 @@ dir.create("data")
 
 # strLs can be of length any length up to 2 billion characters. Starting with
 # 2046 a string is handled as a strL
-dd <- data.frame( dat = paste(replicate(2046, "a"), collapse = ""),
+dd <- data.frame( dat = c(paste(replicate(2046, "a"), collapse = ""),
+                          paste(replicate(2046, "b"), collapse = "")),
                   stringsAsFactors = FALSE)
 
 save.dta13(dd, "data/dta_118.dta", version = 118)
